@@ -6,7 +6,7 @@ use utf8;
 
 package JSON::Relaxed::Parser;
 
-our $VERSION = "0.095";
+our $VERSION = "0.096";
 
 class JSON::Relaxed::Parser;
 
@@ -583,6 +583,7 @@ method encode(%opts) {
     my $prpmode = $opts{prp}                // $prp;
     my $pretty  = $opts{pretty}             // $pretty;
     my $strict  = $opts{strict}             // $strict;
+    my $nouesc  = $opts{nounicodeescapes}   // 0;
 
     if ( $strict ) {
 	$ckeys = $prpmode = $impoh = 0;
@@ -634,7 +635,7 @@ method encode(%opts) {
 	$v =~ s/\013/\\v/g;
 	$v =~ s/\010/\\b/g;
 	$v =~ s/\t/\\t/g;
-	$v =~ s/([^ -ÿ])/sprintf( ord($1) < 0xffff ? "\\u%04x" : "\\u{%x}", ord($1))/ge;
+	$v =~ s/([^ -ÿ])/sprintf( ord($1) < 0xffff ? "\\u%04x" : "\\u{%x}", ord($1))/ge unless $nouesc;
 
 	# Force quotes unless the string can be represented as unquoted.
 	if ( # contains escapes
@@ -757,10 +758,37 @@ method encode(%opts) {
 		$s .= $pr_array->( $v, $level+1, $props->{$k}->{items} );
 	    }
 
+	    elsif ( $pretty ) {
+		my $t = $pr_string->($v);
+		$s .= "$in : ";
+
+		# Break quoted strings that contain pseudo-newlines.
+		if ( $t =~ /^["'`].*\\n/ ) {
+		    # Remove the quotes/
+		    my $quote = substr( $t, 0, 1, '');
+		    chop($t);
+
+		    # Determine current indent.
+		    $s =~ /^(.*)\Z/m;
+		    my $sep = " \\\n" . (" " x length($1));
+
+		    # Get string parts.
+		    my @a = split( /\\n/, $t, -1 );
+		    while ( @a ) {
+			$s .= $quote.shift(@a);
+			$s .= "\\n" if @a;
+			$s .= $quote;
+			$s .= $sep if @a;
+		    }
+		}
+
+		# Just a string.
+		else {
+		    $s .= $t;
+		}
+	    }
 	    else {
-		$s .= $pretty ? "$in : " : ":";
-		$s .= $pr_string->($v);
-		$s .= "," unless $pretty;
+		$s .= ":" . $pr_string->($v) . ",";
 	    }
 	    $s .= "\n" if $pretty;
 	}
@@ -1090,6 +1118,8 @@ method _data_printer( $ddp ) {
 
 # This class distinguises booleans true and false from numeric 1 and 0.
 
+use JSON::PP ();
+
 package JSON::Boolean {
 
     sub as_perl( $self, %options ) { $self }
